lidarwind.data\_operator.GetRestructuredData
============================================

.. currentmodule:: lidarwind.data_operator

.. autoclass:: GetRestructuredData

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GetRestructuredData.__init__
      ~GetRestructuredData.data_transform
      ~GetRestructuredData.data_transform_90
      ~GetRestructuredData.get_coord_non_90
      ~GetRestructuredData.vertical_component_check
   
   

   
   
   